@@ -2,12 +2,8 @@ import numpy as np
 from .functions import isnt_number, interp_nan, init_flag
 import pandas as pd
 from sklearn.cluster import KMeans
-from functools import partial
-from tqdm import tqdm
-from collections import defaultdict
-from tsmoothie import ConvolutionSmoother
 from datetime import datetime
-import warnings
+
 
 def qa_numeric(variable, prior_flags=False):
     """
@@ -33,27 +29,30 @@ def qa_bounds(variable, bounds, prior_flags=False):
     Returns:
         flag (np.array): An array of bools where True means non-trusted data for this outlier dectection
     """
-    data = pd.to_numeric(variable, errors='coerce')
+    #data = pd.to_numeric(variable, errors='coerce').astype(np.float)
+    data = np.squeeze(np.array(pd.DataFrame(variable).apply(pd.to_numeric, errors='coerce').astype(np.float)))
     data[qa_numeric(data)] = np.nan
     flags = init_flag(variable, prior_flags)
     flags[~np.isnan(data)] = np.logical_or(data[~np.isnan(data)] < float(bounds[0]), data[~np.isnan(data)] > float(bounds[1]))
     return flags
 
-def qa_edges(time, edges, prior_flags=False):
+def qa_edges(variable, time, edges, prior_flags=False):
     """
     Indicate values on the edges of the data set
 
     Parameters:
+    variable (np.array): Data array to which to apply the quality assurance
         time (np.array): Time array corresponding to the Data array, time should be in seconds
         edges (int): time (s) in which the data will be cutted on the edges
         prior_flags (np.array): An array of bools where True means non-trusted data
     Returns:
         flag (np.array): An array of bools where True means non-trusted data for this outlier dectection
     """
-    flags = init_flag(time, prior_flags)
-    flags[time > time[-1] - edges] = True
-    flags[time < time[0] + edges] = True
-    return flags
+    flags = np.atleast_2d(init_flag(variable, prior_flags))
+    flags[:,time > time[-1] - edges] = True
+    flags[:,time < time[0] + edges] = True
+    return np.squeeze(flags)
+
 
 def qa_iqr(variable, time, factor=3, prior_flags=False):
     """
@@ -117,7 +116,7 @@ def qa_variation_rate(variable, time, prior_flags=False):
 
         vec_quan = np.quantile(data, quantile_threshold)
         idx_vec = np.where(data >= vec_quan)[0]
-        idx = list(set(idx_vecdiff) & set(idx_vec))
+        idx = list(set(idx_vecdiff) & set(idx_vec)) 
     else:
         idx = []
     flags = np.array(flags, dtype=bool)
@@ -198,65 +197,6 @@ def qa_max(variable, time, factor=3, semiwindow=1000, prior_flags=False):
     flags = np.array(flags, dtype=bool)
     return flags
 
-def qa_convolution(variable, time, window_len=30, window_type='blackman', n_sigma=2, threshold=20,prior_flags =False):
-    """
-        Indicate the trustability of the values using convolutional smoothing of single or multiple time-series
-
-        Parameters:
-            variable (np.array): Data array to which to apply the quality assurance
-            window_len (int) : Greater than equal to 1. The length of the window used to compute
-    the convolutions.
-            window_type (str):  The type of the window used to compute the convolutions.
-    Supported types are: 'ones', 'hanning', 'hamming', 'bartlett', 'blackman'.
-            prior_flags (np.array): An array of bools where True means non-trusted data
-
-        Returns:
-            flags (np.array): An array of bools where True means non-trusted data for this outlier detection
-    """
-    data = interp_nan(time, np.copy(variable))
-    flags = init_flag(time, prior_flags)
-
-    timesteps = len(data)
-
-    series = defaultdict(partial(np.ndarray, shape=(1), dtype='float32'))
-
-    for i in tqdm(range(timesteps + 1), total=(timesteps + 1)):
-        if i > window_len:
-            smoother = ConvolutionSmoother(window_len=window_len, window_type=window_type)
-            smoother.smooth(series['original'][-window_len:])
-
-            series['smooth'] = np.hstack([series['smooth'], smoother.smooth_data[:, -1]])
-
-            _low, _up = smoother.get_intervals('sigma_interval', n_sigma=n_sigma)
-            series['low'] = np.hstack([series['low'], _low[:, -1]])
-            series['up'] = np.hstack([series['up'], _up[:, -1]])
-
-            is_anomaly = np.logical_or(
-                series['original'][-1] > series['up'][-1],
-                series['original'][-1] < series['low'][-1]
-            )
-
-            if is_anomaly.any():
-                series['idx'] = np.hstack([series['idx'], is_anomaly * i]).astype(int)
-
-        if i >= timesteps:
-            continue
-
-        series['original'] = np.hstack([series['original'], data[i]])
-
-    if len(series["idx"]) != 0:
-        idx0 = np.where(series['original'] > threshold)[0]
-        idx = np.intersect1d(idx0, series['idx'])
-        if len(idx) != 0:
-            if idx[-1] == len(data):
-                idx[-1] = idx[-1] - 1
-
-    if len(idx) != 0:
-        flags[idx] = 1
-        flags = np.array(flags, dtype=bool)
-
-    return flags
-
 def qa_kmeans(variable, time, ncluster=2, prior_flags = False):
     """
         Indicate outliers based on kmean clustering.
@@ -324,7 +264,7 @@ def qa_kmeans_threshold(variable, time, ncluster=2, threshold=1.2, prior_flags=F
     flags = np.array(flags, dtype=bool)
     return flags
 
-def qa_maintenance(time,path='./scripts/maintenance_log.csv', prior_flags=False):
+def qa_maintenance(time,path='maintenance_log.csv', prior_flags=False):
     """
         Indicate the trustability of values based on the maintenance logbook
 
@@ -351,3 +291,22 @@ def qa_maintenance(time,path='./scripts/maintenance_log.csv', prior_flags=False)
 
     return flags
 
+
+def qa_individual(time, individual_check, prior_flags = False):
+    """ 
+        Read individual checks and flag 
+        
+        Parameters: 
+            time (np.array): Time array to which to apply the quality assurance
+            individual_check (list): List with points in time having to be removed 
+            prior_flags (np.array): An array of bools where True means non-trusted data
+        Returns:
+            flags (np.array): An array of bools where True means non-trusted data
+            """
+    flags = init_flag(time, prior_flags)
+    for i in individual_check:
+        flag_idx = np.where(i==time)[0]
+        flags[flag_idx] = True
+    return flags
+
+
